@@ -6,15 +6,82 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
-import requests
-import time_box
+from lazysdk import lazyrequests
+from lazysdk import lazytime
 import datetime
 
 
-def business_bm_user_global_var(
+def user_login_status(
+        cookie: str,
+        csrf_token: str = None,  # 非必传字段
+        timeout: int = 5
+):
+    """
+    大账号 检验登录状态，code参数为0是登录状态正常
+    包含UserId参数
+    :param cookie: cookie
+    :param csrf_token: csrf_token
+    :param timeout: 超时时间
+
+    成功返回：
+        {
+            'code': 0,
+            'data': {
+                'CoreUser': {
+                    'UserId': '...'
+                },
+                'FushenUser': {
+                    'Staff': {}
+                },
+                'LoginType': 0,
+                'Advertiser': {
+                    'Id': ''
+                }
+            },
+            'extra': {},
+            'msg': '',
+            'request_id': '...'
+        }
+
+    失败返回：
+        {
+            'code': 40001,
+            'data': {},
+            'extra': {
+                'redirect_url': 'https: //business.oceanengine.com/site/login'
+            },
+            'msg': '未登录',
+            'request_id': '...'
+        }
+
+    """
+    url = 'https://business.oceanengine.com/nbs/api/bm/user/login_status'
+    headers = {
+        "accept": "application/json, text/plain, */*",
+        "accept-encoding": "gzip, deflate",
+        "accept-language": "zh-CN,zh;q=0.9",
+        "cookie": cookie,
+        "referer": "https://business.oceanengine.com",
+        "sec-fetch-mode": "cors",
+        "sec-fetch-site": "same-origin",
+        "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36",
+    }
+    if csrf_token is not None:
+        headers['x-csrftoken'] = csrf_token
+    response = lazyrequests.lazy_requests(
+        method='GET',
+        url=url,
+        headers=headers,
+        timeout=timeout,
+        return_json=True
+    )
+    return response
+
+
+def bm_user_global_var(
         cookie: str,
         csrf_token: str,
-        time_out: int = 5
+        timeout: int = 5
 ):
     """
     【设置】
@@ -81,87 +148,23 @@ def business_bm_user_global_var(
         "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:98.0) Gecko/20100101 Firefox/98.0",
         "x-csrftoken": csrf_token
     }
-    response = requests.request(
+    response = lazyrequests.lazy_requests(
         method='GET',
         url=url,
         headers=headers,
-        timeout=time_out
+        timeout=timeout,
+        return_json=True
     )
-    return response.json()
+    return response
 
 
-def business_bm_user_login_status(
-        cookie: str,
-        csrf_token: str = None,  # 非必传字段
-        time_out: int = 5
-):
-    """
-    大账号
-    检验登录状态
-    成功返回：
-    {
-        'code': 0,
-        'data': {
-            'CoreUser': {
-                'UserId': '...'
-            },
-            'FushenUser': {
-                'Staff': {
 
-                }
-            },
-            'LoginType': 0,
-            'Advertiser': {
-                'Id': ''
-            }
-        },
-        'extra': {
-
-        },
-        'msg': '',
-        'request_id': '...'
-    }
-
-    失败返回：
-    {
-        'code': 40001,
-        'data': {
-
-        },
-        'extra': {
-            'redirect_url': 'https: //business.oceanengine.com/site/login'
-        },
-        'msg': '未登录',
-        'request_id': '...'
-    }
-
-    """
-    url = 'https://business.oceanengine.com/nbs/api/bm/user/login_status'
-    headers = {
-        "accept": "application/json, text/plain, */*",
-        "accept-encoding": "gzip, deflate",
-        "accept-language": "zh-CN,zh;q=0.9",
-        "cookie": cookie,
-        "referer": "https://business.oceanengine.com",
-        "sec-fetch-mode": "cors",
-        "sec-fetch-site": "same-origin",
-        "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36",
-    }
-    if csrf_token is not None:
-        headers['x-csrftoken'] = csrf_token
-    response = requests.request(
-        method='GET',
-        url=url,
-        headers=headers,
-        timeout=time_out
-    )
-    return response.json()
 
 
 def business_bm_user_id(
         cookie: str,
         csrf_token: str,
-        time_out: int = 5
+        timeout: int = 5
 ):
     """
     直接获取user_id
@@ -169,7 +172,7 @@ def business_bm_user_id(
     bm_user_login_status_res = business_bm_user_login_status(
         cookie=cookie,
         csrf_token=csrf_token,
-        time_out=time_out
+        timeout=timeout
     )
     if bm_user_login_status_res['code'] == 0:
         data = bm_user_login_status_res.get('data')
@@ -192,7 +195,7 @@ def business_bm_dashboard_accounts_list(
         csrf_token: str,
         page: int = 1,
         limit: int = 20,
-        time_out: int = 5
+        timeout: int = 5
 ):
     """
     大账号
@@ -215,14 +218,15 @@ def business_bm_dashboard_accounts_list(
         "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:98.0) Gecko/20100101 Firefox/98.0",
         "X-CSRFToken": csrf_token,
     }
-    response = requests.request(
+    response = lazyrequests.lazy_requests(
         method='GET',
         url=url,
         headers=headers,
         allow_redirects=False,
-        timeout=time_out
+        timeout=timeout,
+        return_json=True
     )
-    return response.json()
+    return response
 
 
 def business_bp_statistics_promote_ad_stats_list(
@@ -230,9 +234,9 @@ def business_bp_statistics_promote_ad_stats_list(
         csrf_token: str,
         page: int = 1,
         limit: int = 20,
-        time_out: int = 5,
-        start_time: datetime = time_box.get_relative_datetime(0),
-        end_time: datetime = time_box.get_relative_datetime(1),
+        timeout: int = 5,
+        start_time: datetime = lazytime.get_relative_datetime(0),
+        end_time: datetime = lazytime.get_relative_datetime(1),
 ):
     """
     主账号
@@ -486,15 +490,16 @@ def business_bp_statistics_promote_ad_stats_list(
             }
         }
     }
-    response = requests.request(
+    response = lazyrequests.lazy_requests(
         method='GET',
         url=url,
         headers=headers,
         json=data,
         allow_redirects=False,
-        timeout=time_out
+        timeout=timeout,
+        return_json=True
     )
-    return response.json()
+    return response
 
 
 def bp_statistics_promote_advertiser_stats_list(
@@ -502,7 +507,7 @@ def bp_statistics_promote_advertiser_stats_list(
         csrf_token: str,
         page: int = 1,
         limit: int = 10,  # 10 20 50 100
-        time_out: int = 5,
+        timeout: int = 5,
         start_time: str = None,
         end_time: str = None,
         order_field: str = None,
@@ -514,23 +519,23 @@ def bp_statistics_promote_advertiser_stats_list(
     """
     主账号
     【巨量广告】-【推广】-【账户】
-    :param cookie
-    :param csrf_token
-    :param page 页码，默认为1
-    :param limit 每页数量，默认为10
-    :param time_out 超时时间，单位为秒，默认为5
-    :param start_time 开始时间，默认为当日0点
-    :param end_time 结束时间，默认为次日0点
-    :param order_field 排序列，默认为stat_cost
-    :param order_type 排序方式：默认为1，降序
-    :param cascade_fields 属性设置
-    :param stats_fields 基础指标
-    :param filter_dict 筛选条件
+    :param cookie:
+    :param csrf_token:
+    :param page: 页码，默认为1
+    :param limit: 每页数量，默认为10
+    :param timeout: 超时时间，单位为秒，默认为5
+    :param start_time: 开始时间，默认为当日0点，例如：2022-03-21 00:00:00
+    :param end_time: 结束时间，默认为次日0点，例如：2022-03-22 00:00:00
+    :param order_field: 排序列，默认为stat_cost
+    :param order_type: 排序方式：默认为1，降序
+    :param cascade_fields: 属性设置
+    :param stats_fields: 基础指标
+    :param filter_dict: 筛选条件
     """
     if start_time is None:
-        start_time = time_box.get_relative_datetime(0)
+        start_time = lazytime.get_datetime_relative(0)
     if end_time is None:
-        end_time = time_box.get_relative_datetime(1)
+        end_time = lazytime.get_datetime_relative(1)
     if order_field is None:
         order_field = 'stat_cost'  # 默认按照消耗排序
     if order_type is None:
@@ -584,11 +589,12 @@ def bp_statistics_promote_advertiser_stats_list(
         "stats_fields": stats_fields,
         "filter": filter_dict
     }
-    response = requests.request(
+    response = lazyrequests.lazy_requests(
         method='POST',
         url=url,
         headers=headers,
         json=data,
-        timeout=time_out
+        timeout=timeout,
+        return_json=True
     )
-    return response.json()
+    return response
